%define anolis_release 4

%bcond_with java

Name:           capstone
Version:        4.0.2
Release:        %{anolis_release}%{?dist}
Summary:        A lightweight multi-platform, multi-architecture disassembly framework
License:        BSD
URL:            http://www.capstone-engine.org/
Source0:        https://github.com/capstone-engine/capstone/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  make

%ifarch %{java}
BuildRequires:  jna
BuildRequires:  java-devel
BuildRequires:  /usr/bin/python
%endif

BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%description
Capstone is a disassembly framework with the target of becoming the ultimate
disasm engine for binary analysis and reversing in the security community.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        -n python3-capstone
%{?python_provide:%python_provide python3-capstone}
Provides:       %{name}-python3 = %{version}-%{release}
Obsoletes:      %{name}-python3 < %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Summary:        Python3 bindings for %{name}


%description    -n python3-capstone
The python3-capstone package contains python3 bindings for %{name}.


%ifarch %{java}
%package        java
Summary:        Java bindings for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    java
The %{name}-java package contains java bindings for %{name}.
%endif

%package        doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
Doc files for %{name}

%prep
%autosetup -p1 -n %{name}-%{version}

%build
V=1 CFLAGS="%{optflags}" \
PREFIX="%{_prefix}" LIBDIRARCH="%{_lib}" INCDIR="%{_includedir}" \
%make_build PYTHON3=%{__python3}
 
# Fix pkgconfig file
grep -v archive capstone.pc > capstone.pc.tmp
mv capstone.pc.tmp capstone.pc
 
# build python bindings
pushd bindings/python
%py3_build
popd
 
%ifarch %{java}
pushd bindings/java
%make_build PYTHON3=%{__python3} CFLAGS="%{optflags}"
popd
%endif
 
%install
DESTDIR=%{buildroot} PREFIX="%{_prefix}" LIBDIRARCH=%{_lib} \
INCDIR="%{_includedir}" make install
find %{buildroot} -name '*.a' -exec rm -f {} ';'
 
pushd bindings/python
%py3_install
popd
 
%ifarch %{java}
install -D -p -m 0644 bindings/java/%{name}.jar  %{buildroot}/%{_javadir}/%{name}.jar
%endif 
 
%generate_compatibility_deps

%check
ln -s libcapstone.so.4 libcapstone.so
make check LD_LIBRARY_PATH="`pwd`"

%files
%license LICENSE.TXT LICENSE_LLVM.TXT
%{_libdir}/*.so.*
%{_bindir}/cstool
%dir %{abidir}
%{abidir}/libcapstone.dump
%{abidir}/cstool-option.list

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%files -n python%{python3_pkgversion}-capstone
%{python3_sitelib}/*egg-info
%{python3_sitelib}/%{name}

%ifarch %{java}
%files java
%{_javadir}/
%endif

%files doc
%doc CREDITS.TXT ChangeLog README.md SPONSORS.TXT

%changelog
* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 4.0.2-4
- Rebuild with python3.11

* Wed Dec 20 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.0.2-3
- rebuild

* Sat Mar 25 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 4.0.2-2
- Strip java sub-package

* Thu Mar 9 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 4.0.2-1
- init from upstream
